(* ::Package:: *)

BeginPackage["BaseFunctions`"]
Unprotect@@Names["BaseFunctions`*"];
ClearAll@@Names["BaseFunctions`*"];

SetDirectory[Directory[]];
out=Quiet[<<BaseUsefulConstants`];
iF[out== $Failed,
	SetDirectory[NotebookDirectory[]];
	Quiet[<<BaseUsefulConstants`]
];

factAuxUdip::usage="Used for polarizability"

IFun::usage="IFun[PowerBeam_,waist1_,waist2_]"
IComp::usage="IComp[PowerBeam_,waist1_,waist2_]"
UdipFun::usage="UdipFun[IBeam_,\[Alpha]_], in Hz"
UdipComp::usage="UdipComp[IBeam_,\[Alpha]_]"
ZRayleighFun::usage="ZRayleighFun[lambda_, waist_, Msquared_]"
ZRayleighComp::usage="ZRayleighComp[lambda_, waist_, Msquared_]"
DipPotFun::usage="DipPotFun[XX_, YY_, ZZ_, Udip_, waistXX_, waistYY_, ZRayleighX_, ZRayleighY_]"
DipPotComp::usage="DipPotComp[XX_, YY_, ZZ_, Udip_, waistXX_, waistYY_, ZRayleighX_, ZRayleighY_]"
DipPotRotFun::usage="DipPotRotFun[XX_, YY_, ZZ_, Udip_, waistXX_, waistYY_, ZRayleighX_, ZRayleighY_, \[CapitalTheta]_, \[Phi]_, XX0_, YY0_, ZZ0_]"
DipPotRotComp::usage="DipPotRotComp[XX_, YY_, ZZ_, Udip_, waistXX_, waistYY_, ZRayleighX_, ZRayleighY_, \[CapitalTheta]_, \[Phi]_, XX0_, YY0_, ZZ0_]"
DipPotTotFun::usage="DipPotTotFun[xx_, yy_, zz_, laserTab_]"
DipPotTotComp::usage="DipPotTotFun[xx_, yy_, zz_, laserTab_]"
gravPotFun::usage="gravPotFun[yy_, mAss_]"
gravPotComp::usage="gravPotComp[yy_, mAss_]"
DipPotTotPlusSaggingFun::usage="DipPotTotPlusSaggingFun[xx_, yy_, zz_, laserTab_, mAss_]"




IsatFun::usage="IsatFun[\[CapitalGamma]_, \[Lambda]_]"
IsatComp::usage="IsatComp[\[CapitalGamma]_, \[Lambda]_]"
scatRateFun::usage="scatRateFun[\[CapitalGamma]_, SatPar_, \[Delta]_]"
scatRateComp::usage="scatRateComp[\[CapitalGamma]_, SatPar_, \[Delta]_]"
scatRateWithSatParamMultFun::usage="scatRateWithSatParamMultFun[\[CapitalGamma]_,satParam_,satParamTot_]"
scatRateWithSatParamMultComp::usage="scatRateWithSatParamMultComp[\[CapitalGamma]_,satParam_,satParamTot_]"

\[Lambda]dBFun::usage="\[Lambda]dBFun[T_,mAss_]"





Begin["`Private`"]


(* Dipole trap *)
factAuxUdip = (4.* Pi * \[Epsilon]0 * aB^3.)/\[Epsilon]0/cLum/2./ctePlanck;

IFun[PowerBeam_,waist1_,waist2_]:= 2.*PowerBeam/(Pi*waist1*waist2);
IComp=Compile[{PowerBeam,waist1,waist2},IFun[PowerBeam,waist1,waist2]];

UdipFun[IBeam_,\[Alpha]_]:= IBeam*\[Alpha] *factAuxUdip ;
UdipComp=Compile[{IBeam,\[Alpha]},UdipFun[IBeam,\[Alpha]]];

ZRayleighFun[lambda_, waist_, Msquared_]:= Pi * waist^2./lambda/Msquared;
ZRayleighComp=Compile[{lambda, waist, Msquared},ZRayleighFun[lambda, waist, Msquared]];

DipPotFun[XX_, YY_, ZZ_, Udip_, waistXX_, waistYY_, ZRayleighX_, ZRayleighY_]:=Module[{ZRayXAux,ZRayYAux},
ZRayXAux =Sqrt[1.+(ZZ/ZRayleighX)^2.];
ZRayYAux = Sqrt[1.+(ZZ/ZRayleighY)^2.];
-Udip/(ZRayXAux *ZRayYAux)* Exp[-2.*((XX/(waistXX *ZRayXAux ))^2.+(YY/(waistYY *ZRayYAux))^2.)]
];
DipPotComp=Compile[{ XX, YY, ZZ,Udip,waistXX,waistYY,ZRayleighX,ZRayleighY},DipPotFun[ XX, YY, ZZ,Udip,waistXX,waistYY,ZRayleighX,ZRayleighY]];

DipPotRotFun[XX_, YY_, ZZ_, Udip_, waistXX_, waistYY_, ZRayleighX_, ZRayleighY_, \[CapitalTheta]_, \[Phi]_, XX0_, YY0_, ZZ0_]:=Module[{Xshift,Yshift,Zshift,XRot,YRot,ZRot,XRot2,YRot2,ZRot2},
Xshift = XX-XX0;
Yshift = YY-YY0;
Zshift = ZZ-ZZ0;
XRot= Xshift*Cos[\[CapitalTheta]] - Yshift *Sin[\[CapitalTheta]];
YRot= Xshift*Sin[\[CapitalTheta]] + Yshift *Cos[\[CapitalTheta]];
ZRot= Zshift;
XRot2 = XRot;
YRot2 = YRot*Cos[\[Phi]] - ZRot *Sin[\[Phi]];
ZRot2 = YRot*Sin[\[Phi]] + ZRot *Cos[\[Phi]];
DipPotFun[XRot2, YRot2, ZRot2, Udip, waistXX, waistYY, ZRayleighX, ZRayleighY]
];
DipPotRotComp=Compile[{XX, YY, ZZ, Udip, waistXX, waistYY, ZRayleighX, ZRayleighY, \[CapitalTheta], \[Phi], XX0, YY0, ZZ0},DipPotRotFun[XX, YY, ZZ, Udip, waistXX, waistYY, ZRayleighX, ZRayleighY, \[CapitalTheta], \[Phi], XX0, YY0, ZZ0]];

DipPotTotFun[xx_, yy_, zz_, laserTab_]:=Total[(Apply[DipPotRotFun,Join[{xx,yy,zz},#]])&/@laserTab];
DipPotTotComp[xx_, yy_, zz_, laserTab_]:=Total[(Apply[DipPotRotComp,Join[{xx,yy,zz},#]])&/@laserTab];

gravPotFun[yy_, mAss_]:=- mAss *gForce * yy/ctePlanckOverAu;
gravPotComp=Compile[{yy, mAss},gravPotFun[yy, mAss]];

DipPotTotPlusSaggingFun[xx_, yy_, zz_, laserTab_, mAss_]:=DipPotTotFun[xx, yy, zz, laserTab] + gravPotFun[yy, mAss];



(* Optical scattering *)
IsatFun[\[CapitalGamma]_, \[Lambda]_]:= Pi * ctePlanck * cLum * \[CapitalGamma] / (3. * \[Lambda]^3.);
crossSectionFun[\[Lambda]_]:= 3. * \[Lambda]^2. / (2. * Pi);
IsatComp=Compile[{\[CapitalGamma], \[Lambda]},IsatFun[\[CapitalGamma], \[Lambda]]];

scatRateFun[\[CapitalGamma]_, SatPar_, \[Delta]_]:= \[CapitalGamma]/2. * SatPar/(1. + SatPar + 4.*(\[Delta]/\[CapitalGamma])^2.);
scatRateComp:=Compile[{{\[CapitalGamma],_Real}, {SatPar,_Real}, {\[Delta],_Real}},scatRateFun[\[CapitalGamma], SatPar, \[Delta]]];

scatRateWithSatParamMultFun[\[CapitalGamma]_,satParam_,satParamTot_]:= \[CapitalGamma]/ 2.*satParam/(1.+satParamTot);
scatRateWithSatParamMultFun=Compile[{\[CapitalGamma],satParam,satParamTot},scatRateWithSatParamMultFun[\[CapitalGamma],satParam,satParamTot]]

(* BECs *)
\[Lambda]dBFun[T_,mAss_]:=Sqrt[2.*Pi/(mAss * T)*hbarreOverAu * hbarreOverkB];



End[]
Protect@@Names["BaseFunctions`*"];
EndPackage[]
