(* ::Package:: *)

Quiet[BeginPackage["`BaseUsefulConstants`"], {General::obspkg, General::newpkg}]

ctePlanck::usage = "Planck's constant"
hbarre::usage = "Planck's constant divided by 2 \[Pi]"
cLum::usage = "Speed of light"
kB::usage = "Boltzmann's constant"
aB::usage = "Bohr's radius"
\[Mu]B::usage = "Bohr's magneton"
hartree::usage = "hartree energy unit"
\[Mu]0::usage = "vacuum permeability"
\[Epsilon]0::usage = "vacuum permittivity"
au::usage = "atomic mass unit, Dalton"
eElec::usage = "elementary electric charge"
gForce::usage = "gravitational acceleration"
Debye::usage = "debye"
Na::usage = "Avogadro number" 

ctePlanck = 6.62607015*10^(-34); (* J . s ; exactly defined *)
hbarre    = ctePlanck / (2*Pi);
cLum      = 2.99792458*10^8; (* m / s ; exactly defined *)
kB        = 1.380649*10^(-23); (* J/K  ; exactly defined *)
aB        = 52.9177210903 * 10^(-12); (* m ; from wikipedia, CODATA 18 *)
\[Mu]B        = 9.274009994 * 10^(-24); (* J/T ; from wikipedia *)
hartree   = 4.3597447222071*10^(-18); (* J ; from wikipedia CODATA 18 *)
\[Mu]0        = 1.25663706212*10^(-6); (* H/m ; not anymore defined as 4.*Pi*10^(-7) *)
\[Epsilon]0        = 1/(\[Mu]0 *cLum^2); (* F / m *)
au        = 1.66053906660*10^(-27); (* kg ; from wikipedia *)
eElec     = 1.602176634*10^(-19); (* C ; exactly defined *)
gForce    = 9.80665; (* m.s^-2 ; conventional standard value *)
Debye     = 1/cLum*10^(-21); (* C . m *)
Na        = 6.02214076; (* dimensionless ; exactly defined CODATA 18 *)


ctePlanckOverAu = ctePlanck/au;
auOverCtePlanck = au/ctePlanck;
ctePlanckOverkB = ctePlanck/kB;
kBOverCtePlanck = kB/ctePlanck;
auOverkB= au/kB;
kBOverAu = kB/au;
hbarreOverAu = hbarre /au;
hbarreOverkB = hbarre / kB;
hbarreOver\[Mu]B = hbarre / \[Mu]B;
\[Mu]BOverHbarre = \[Mu]B / hbarre;
kBOverHbarre= kB/hbarre;
auOverHbarre= au/hbarre;

Ridealgad = Na * kB;



EndPackage[]






