(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     90538,       2119]
NotebookOptionsPosition[     86220,       1990]
NotebookOutlinePosition[     86585,       2006]
CellTagsIndexPosition[     86542,       2003]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 StyleBox[
  RowBox[{"Rate", " ", "Equation", " ", "for", " ", "SS", " ", "BEC"}], 
  "Title"]], "Input",
 CellChangeTimes->{{3.7877230045764613`*^9, 3.787723021518431*^9}}],

Cell[BoxData[
 StyleBox[Cell[TextData[StyleBox["Remark: Notes in pdf to be added",
   FontFamily->"Times New Roman",
   FontSize->14,
   FontWeight->"Plain"]]], "DisplayFormula"]], "Input",
 CellChangeTimes->{{3.7877230389217367`*^9, 3.787723061734108*^9}, 
   3.787723291671734*^9}],

Cell[BoxData[Cell[TextData[StyleBox["This is the rate equation with \
1,2,3-body losses and pump p",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Plain"]]]], "Input",
 CellChangeTimes->{{3.7877233313387613`*^9, 3.7877233548703623`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"n", "'"}], "[", "t", "]"}], "=", 
  RowBox[{
   RowBox[{"\[Gamma]3", " ", 
    SuperscriptBox[
     RowBox[{"n", "[", "t", "]"}], "3"]}], "+", 
   RowBox[{"\[Gamma]2", " ", 
    SuperscriptBox[
     RowBox[{"n", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"\[Gamma]1", " ", 
    RowBox[{"n", "[", "t", "]"}]}], " ", "-", " ", 
   RowBox[{"\[Gamma]p", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"n", "[", "t", "]"}], "+", "1"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.787723360666478*^9, 3.7877233930143337`*^9}}],

Cell[BoxData[Cell[TextData[StyleBox["The SS solution is given by solving a \
cubic polynomial; Analytic expressions are in principle available, but ugly \
and not so insightful",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Plain"]]]], "Input",
 CellChangeTimes->{{3.787723399571973*^9, 3.7877234578312473`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]3", " ", 
        SuperscriptBox["n", "3"]}], "+", 
       RowBox[{"\[Gamma]2", " ", 
        SuperscriptBox["n", "2"]}], "+", 
       RowBox[{"\[Gamma]1", " ", "n"}], " ", "-", " ", 
       RowBox[{"\[Gamma]p", 
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}]}]}], "\[Equal]", "0"}], ",", "n"}], 
    "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7876670727319174`*^9, 3.7876671102717457`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Solve was unable to solve the system with inexact \
coefficients. The answer was obtained by solving a corresponding exact system \
and numericizing the result. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::ratnz\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.788348899036313*^9, 3.788348935191663*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5`"}], " ", "\[Gamma]2"}], "-", 
       RowBox[{"0.5`", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["\[Gamma]2", "2"], "-", 
          RowBox[{"4.`", " ", "\[Gamma]1", " ", "\[Gamma]3"}]}]]}]}], 
      "\[Gamma]3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", 
     FractionBox[
      RowBox[{"0.5`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1.`"}], " ", "\[Gamma]2"}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["\[Gamma]2", "2"], "-", 
           RowBox[{"4.`", " ", "\[Gamma]1", " ", "\[Gamma]3"}]}]]}], ")"}]}], 
      "\[Gamma]3"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7883488990973563`*^9, 3.788348935235694*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Gamma]3", " ", 
      SuperscriptBox["n", "3"]}], "+", 
     RowBox[{"\[Gamma]2", " ", 
      SuperscriptBox["n", "2"]}], "+", 
     RowBox[{"\[Gamma]1", " ", "n"}], " ", "-", " ", 
     RowBox[{"\[Gamma]p", 
      RowBox[{"(", 
       RowBox[{"n", "+", "1"}], ")"}]}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"SS", " ", "polynomial"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.787667294917568*^9, 3.7876672998870816`*^9}, {
   3.78772348017301*^9, 3.7877234855087996`*^9}, 3.787723542066753*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", Cell[TextData[StyleBox[
  "pick up some random numbers for the decay rates",
   FontFamily->"Times New Roman",
   FontSize->14,
   FontWeight->"Plain"]]]}]], "Input",
 CellChangeTimes->{{3.7877235070480266`*^9, 3.787723533051383*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]3", "=", "0.01"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]2", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]1", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7876673031824017`*^9, 3.7876673262697163`*^9}, {
  3.7877234900940485`*^9, 3.7877235045662737`*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"STEADY", " ", "STATE"}], "Section"]], "Input",
 CellChangeTimes->{{3.787668323351925*^9, 3.787668334850048*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]p", "=", "\[Gamma]pin"}], ";", 
      RowBox[{"p", "[", "n", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "10"}], "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "All"}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "\"\<p[n]\>\""}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"\[Gamma]pin", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7876673275025883`*^9, 3.7876673905921707`*^9}, {
  3.787667442430786*^9, 3.787667444640354*^9}, {3.7877235537360125`*^9, 
  3.7877235621679473`*^9}, {3.7877242594098253`*^9, 3.7877242779019203`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`\[Gamma]pin$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`\[Gamma]pin$$], 0, 5}}, Typeset`size$$ = {
    360., {113., 118.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`\[Gamma]pin$1376$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`\[Gamma]pin$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Gamma]pin$$, $CellContext`\[Gamma]pin$1376$$, 0]},
       "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[$CellContext`\[Gamma]p = $CellContext`\[Gamma]pin$$; \
$CellContext`p[$CellContext`n], {$CellContext`n, 0, 10}, 
        PlotRange -> {Automatic, All}, AxesLabel -> {None, "p[n]"}], 
      "Specifications" :> {{$CellContext`\[Gamma]pin$$, 0, 5}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{409., {159., 164.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.787667358160242*^9, 3.787667391543825*^9}, 
   3.787723563059569*^9, 3.7877242785773683`*^9, 3.788348947328251*^9}]
}, Open  ]],

Cell[BoxData[
 StyleBox["DYNAMICS", "Section"]], "Input",
 CellChangeTimes->{{3.787667560482032*^9, 3.7876675606031246`*^9}, 
   3.787668272273833*^9, {3.7876683434411097`*^9, 3.787668344922165*^9}, 
   3.7876686488804502`*^9}],

Cell[BoxData[Cell[TextData[Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      StyleBox[Cell["\<\
Solve for the dynamics starting from some initial state (say no condensate, \
n[0]\[Equal]0)\
\>", "Text",
        FontFamily->"Times New Roman"],
       FontFamily->"Courier New"], 
      StyleBox[
       RowBox[{";", " ", 
        RowBox[{"In", " ", "its", " ", "present", " ", "form"}]}],
       FontFamily->"Times New Roman"]}], 
     StyleBox[",",
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FontFamily->"Times New Roman"], 
     StyleBox[
      RowBox[{
      "the", " ", "rate", " ", "equation", " ", "can", " ", "be", " ", 
       "solved", " ", "analytically"}],
      FontFamily->"Times New Roman"], 
     StyleBox[",",
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FontFamily->"Times New Roman"], 
     StyleBox[
      RowBox[{"rather", " ", "than", " ", 
       RowBox[{"numerically", "."}]}],
      FontFamily->"Times New Roman"]}], "Text",
    FontSize->14,
    FontWeight->"Plain"], TraditionalForm]],
  FormatType->"TraditionalForm"]],
  FontFamily->"Times New Roman"]], "Input",
 CellChangeTimes->{{3.7877236063731875`*^9, 3.787723808137756*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"g", " ", 
       RowBox[{"n", "[", "t", "]"}]}], "-", 
      RowBox[{"g2", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"g3", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "3"]}]}]}], ",", 
    RowBox[{"n", "[", "t", "]"}], ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7876687651754694`*^9, 3.7876689292163677`*^9}, 
   3.7876691045685735`*^9, {3.787669460630685*^9, 3.787669473990121*^9}, 
   3.787670702822966*^9, 3.7877238271341877`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"InverseFunction", "[", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", "g2", " ", 
            RowBox[{"ArcTan", "[", 
             FractionBox[
              RowBox[{"g2", "+", 
               RowBox[{"2", " ", "g3", " ", "#1"}]}], 
              SqrtBox[
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["g2", "2"]}], "-", 
                RowBox[{"4", " ", "g", " ", "g3"}]}]]], "]"}]}], 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["g2", "2"]}], "-", 
             RowBox[{"4", " ", "g", " ", "g3"}]}]]], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", "#1", "]"}]}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{"g", "-", 
            RowBox[{"#1", " ", 
             RowBox[{"(", 
              RowBox[{"g2", "+", 
               RowBox[{"g3", " ", "#1"}]}], ")"}]}]}], "]"}]}], 
         RowBox[{"2", " ", "g"}]]}], "&"}], "]"}], "[", 
     RowBox[{"t", "+", 
      RowBox[{"C", "[", "1", "]"}]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.787668802902115*^9, {3.787668843851046*^9, 3.7876689299128504`*^9}, 
   3.7876691052740636`*^9, {3.7876694613591795`*^9, 3.787669474621563*^9}, 
   3.787670703835043*^9, 3.7877238371392307`*^9, 3.7883489610169106`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", "sol"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"g", "\[Rule]", "1"}], ",", 
         RowBox[{"g2", "\[Rule]", "g2in"}], ",", 
         RowBox[{"g3", "\[Rule]", "g3in"}], ",", 
         RowBox[{
          RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
          RowBox[{"-", "1"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "15"}], "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<n[t]\>\""}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"g2in", ",", "0.01", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"g3in", ",", "0.01", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7876689339256725`*^9, 3.7876691458427134`*^9}, {
  3.787669226995079*^9, 3.7876692668907113`*^9}, {3.7876693179147587`*^9, 
  3.7876693226981387`*^9}, {3.787669367912074*^9, 3.7876694124325285`*^9}, {
  3.7877242889537663`*^9, 3.7877243049831*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`g2in$$ = 0.01, $CellContext`g3in$$ = 0.01, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`g2in$$], 0.01, 2}, {
      Hold[$CellContext`g3in$$], 0.01, 2}}, Typeset`size$$ = {
    360., {122., 125.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`g2in$170081$$ = 
    0, $CellContext`g3in$170082$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`g2in$$ = 0.01, $CellContext`g3in$$ = 0.01},
       "ControllerVariables" :> {
        Hold[$CellContext`g2in$$, $CellContext`g2in$170081$$, 0], 
        Hold[$CellContext`g3in$$, $CellContext`g3in$170082$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        Evaluate[
         ReplaceAll[
          ReplaceAll[
           $CellContext`n[$CellContext`t], $CellContext`sol], {$CellContext`g -> 
           1, $CellContext`g2 -> $CellContext`g2in$$, $CellContext`g3 -> \
$CellContext`g3in$$, C[1] -> -1}]], {$CellContext`t, 0, 15}, 
        PlotRange -> {All, {0, Automatic}}, AxesLabel -> {"t", "n[t]"}], 
      "Specifications" :> {{$CellContext`g2in$$, 0.01, 
         2}, {$CellContext`g3in$$, 0.01, 2}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{409., {181., 186.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.7876689789655094`*^9, 3.7876690292400165`*^9}, {
   3.7876691354173603`*^9, 3.7876691462820363`*^9}, {3.7876692287763042`*^9, 
   3.787669267721266*^9}, 3.7876693239770107`*^9, {3.787669393768319*^9, 
   3.7876694135933304`*^9}, 3.787724306485137*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7883488925377226`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.78834889254973*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7883488925507307`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ReplaceAll :: reps\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7883488925577354`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887760071727037`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.78877600718071*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887760071826963`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ReplaceAll :: reps\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788776007189701*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887785355031824`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778535525167*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.78877853552917*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ReplaceAll :: reps\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778535533173*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.78878575453905*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788785754557073*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({sol}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887857545600753`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ReplaceAll :: reps\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887857545640774`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7876691647961173`*^9, 3.787669219173537*^9}, 
   3.7877238618447156`*^9}],

Cell[BoxData[
 FormBox[Cell[TextData[StyleBox[
  "Furthermore, when either the two or three body losses are neglected, the \
analytical solution further simplifies, yielding a simple solution for n[t]",
   FontFamily->"Times New Roman",
   FontSize->14,
   FontWeight->"Plain"]]], TraditionalForm]], "Input",
 CellChangeTimes->{3.787723875001011*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol0", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"g", " ", 
       RowBox[{"n", "[", "t", "]"}]}], "-", 
      RowBox[{"0", "g2", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"g3", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"0", "gp"}]}]}], ",", 
    RowBox[{"n", "[", "t", "]"}], ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7876687651754694`*^9, 3.7876689292163677`*^9}, 
   3.7876691045685735`*^9, {3.787669460630685*^9, 3.787669473990121*^9}, 
   3.787670702822966*^9, 3.7877238271341877`*^9, {3.787724114371496*^9, 
   3.787724117034375*^9}, {3.7883497455739646`*^9, 3.788349751596216*^9}, {
   3.788349785858415*^9, 3.7883497886463957`*^9}, {3.7883515058133802`*^9, 
   3.7883515225592155`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"g", " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", 
        SqrtBox["g"]}], 
       SqrtBox[
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "g", " ", 
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", "g3"}]}]]]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"g", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", 
           RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", 
       SqrtBox["g"]}], 
      SqrtBox[
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "g", " ", 
           RowBox[{"(", 
            RowBox[{"t", "+", 
             RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", "g3"}]}]]]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.787668802902115*^9, {3.787668843851046*^9, 3.7876689299128504`*^9}, 
   3.7876691052740636`*^9, {3.7876694613591795`*^9, 3.787669474621563*^9}, 
   3.787670703835043*^9, 3.7877238371392307`*^9, 3.787724119564155*^9, 
   3.7883491928727646`*^9, 3.788349753369446*^9, 3.7883497894179277`*^9, {
   3.788351509092693*^9, 3.7883515353342347`*^9}, 3.7887785517966433`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", 
        RowBox[{"sol0", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"g", "\[Rule]", "1"}], ",", 
         RowBox[{"g2", "\[Rule]", "g2in"}], ",", 
         RowBox[{"g3", "\[Rule]", "g3in"}], ",", 
         RowBox[{
          RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"-", "1"}], " ", "0"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "15"}], "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<n[t]\>\""}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"g2in", ",", "0.01", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"g3in", ",", "0.01", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7876689339256725`*^9, 3.7876691458427134`*^9}, {
  3.787669226995079*^9, 3.7876692668907113`*^9}, {3.7876693179147587`*^9, 
  3.7876693226981387`*^9}, {3.787669367912074*^9, 3.7876694124325285`*^9}, {
  3.787724123792161*^9, 3.7877241429496913`*^9}, {3.787724318177413*^9, 
  3.787724322295333*^9}, {3.788349213372574*^9, 3.7883492266499557`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Gamma]p", "=", "3"}], ";", " ", 
  RowBox[{"\[Gamma]3", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"\[Gamma]p", ",", "\[Gamma]1", ",", "\[Gamma]2", ",", "\[Gamma]3"}],
   "}"}]}], "Input",
 CellChangeTimes->{{3.788349676733124*^9, 3.7883497152513494`*^9}, {
  3.7883498560189967`*^9, 3.788349871470882*^9}, {3.788350117649929*^9, 
  3.788350124590822*^9}, {3.78835023360885*^9, 3.7883502621860485`*^9}, {
  3.7883503272620955`*^9, 3.788350337765499*^9}, {3.7883541458315444`*^9, 
  3.7883541458705716`*^9}, {3.788354189886667*^9, 3.788354190200876*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "1", ",", "0.01`", ",", "0.01`"}], "}"}]], "Output",
 CellChangeTimes->{3.788354190341975*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"soln", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Gamma]1"}], " ", 
          RowBox[{"n", "[", "t", "]"}]}], "-", 
         RowBox[{"0", "g2", " ", 
          SuperscriptBox[
           RowBox[{"n", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"\[Gamma]3", " ", 
          SuperscriptBox[
           RowBox[{"n", "[", "t", "]"}], "3"]}], "+", " ", 
         RowBox[{"\[Gamma]p", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"n", "[", "t", "]"}], "+", "1"}], ")"}]}]}]}], ",", 
       RowBox[{
        RowBox[{"n", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", "n", 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788349445298443*^9, 3.7883495128511705`*^9}, {
  3.788349622093525*^9, 3.7883496307106247`*^9}, {3.7883501392431803`*^9, 
  3.7883501394283185`*^9}, {3.7883541652072167`*^9, 3.788354171023326*^9}},
 CellID->5423],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"n", "[", "t", "]"}], "/.", "soln"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"n", "[", "t", "]"}], "/.", 
          RowBox[{"sol0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"g", "\[Rule]", 
            RowBox[{"\[Gamma]p", "-", "\[Gamma]1"}]}], ",", 
           RowBox[{"g3", "\[Rule]", "\[Gamma]3"}], ",", 
           RowBox[{
            RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
            RowBox[{"f", " ", 
             RowBox[{"Log", "[", 
              RowBox[{"\[Gamma]p", "/", 
               SqrtBox[
                RowBox[{"\[Gamma]p", "-", "\[Gamma]1", "-", 
                 RowBox[{
                  SuperscriptBox["\[Gamma]p", "2"], "\[Gamma]3"}]}]]}], 
              "]"}]}]}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "\[IndentingNewLine]", 
   ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", 
     RowBox[{"-", "1"}], ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.788349519907171*^9, 3.788349527752697*^9}, 
   3.7883501455826373`*^9, {3.788350278307438*^9, 3.788350322047414*^9}, {
   3.788351272983718*^9, 3.788351276902486*^9}, {3.7883515823844132`*^9, 
   3.7883516482099485`*^9}, {3.7883516924632063`*^9, 3.7883517641622105`*^9}},
 CellID->28908],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`f$$ = -1., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`f$$], -1, 5}}, Typeset`size$$ = {360., {109., 112.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`f$73398$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`f$$ = -1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`f$$, $CellContext`f$73398$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[{
         Evaluate[
          ReplaceAll[
           $CellContext`n[$CellContext`t], $CellContext`soln]], 
         Evaluate[
          ReplaceAll[
           ReplaceAll[
            $CellContext`n[$CellContext`t], 
            
            Part[$CellContext`sol0, 
             2]], {$CellContext`g -> $CellContext`\[Gamma]p - $CellContext`\
\[Gamma]1, $CellContext`g3 -> $CellContext`\[Gamma]3, 
            C[1] -> $CellContext`f$$ 
             Log[$CellContext`\[Gamma]p/($CellContext`\[Gamma]p - \
$CellContext`\[Gamma]1 - $CellContext`\[Gamma]p^2 $CellContext`\[Gamma]3)^
               Rational[1, 2]]}]]}, {$CellContext`t, 0, 5}, PlotRange -> All],
       "Specifications" :> {{$CellContext`f$$, -1, 5}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{409., {154., 159.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.788349528502228*^9, 3.7883496385251255`*^9, {3.788349706597207*^9, 
   3.7883497178131437`*^9}, {3.788349858638816*^9, 3.788349874134779*^9}, {
   3.7883501207210712`*^9, 3.7883501482065067`*^9}, {3.788350243387738*^9, 
   3.7883502917319765`*^9}, {3.788350322500716*^9, 3.7883503407976427`*^9}, 
   3.788351648939433*^9, {3.788351709576288*^9, 3.7883517643533144`*^9}, {
   3.788354157138516*^9, 3.7883541994594164`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({soln}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788776011456712*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({soln}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887760114577255`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({soln}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788776011458725*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ReplaceAll :: reps\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887760114597135`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\({0.00010214285714285715`}\\)\
\[NoBreak] lies outside the range of data in the interpolating function. \
Extrapolation will be used. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.7887784473300467`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partd"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part specification \[NoBreak]\\!\\(sol0 \
\[LeftDoubleBracket] 2 \[RightDoubleBracket]\\)\[NoBreak] is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/partd\\\", ButtonNote -> \
\\\"Part::partd\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887784473430414`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(sol0 \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887784473450427`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partd"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part specification \[NoBreak]\\!\\(sol0 \
\[LeftDoubleBracket] 2 \[RightDoubleBracket]\\)\[NoBreak] is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/partd\\\", ButtonNote -> \
\\\"Part::partd\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778447347044*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(sol0 \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778447348045*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(sol0 \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778447350046*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ReplaceAll :: reps\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887784473510466`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\({0.09814330600765199`}\\)\
\[NoBreak] lies outside the range of data in the interpolating function. \
Extrapolation will be used. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.788778447359065*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\({0.20454178542729323`}\\)\
\[NoBreak] lies outside the range of data in the interpolating function. \
Extrapolation will be used. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.7887784473610544`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(InterpolatingFunction :: dmval\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778447362071*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partd"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part specification \[NoBreak]\\!\\(sol0 \
\[LeftDoubleBracket] 2 \[RightDoubleBracket]\\)\[NoBreak] is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/partd\\\", ButtonNote -> \
\\\"Part::partd\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778532781233*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(sol0 \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887785327832465`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(sol0 \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778532784251*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(sol0 \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.788778532786253*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ReplaceAll :: reps\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887785327872534`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\({0.09814330600765199`}\\)\
\[NoBreak] lies outside the range of data in the interpolating function. \
Extrapolation will be used. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.78877853279324*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\({0.20454178542729323`}\\)\
\[NoBreak] lies outside the range of data in the interpolating function. \
Extrapolation will be used. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.788778532794243*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\({0.30388941785076046`}\\)\
\[NoBreak] lies outside the range of data in the interpolating function. \
Extrapolation will be used. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.7887785327962427`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(InterpolatingFunction :: dmval\\), \
\\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7887785327972555`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"p", "[", "n", "]"}], "\[Equal]", "0"}], ",", "n"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.788354055442168*^9, 3.788354087639432*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", 
     RowBox[{"-", "13.864585163414702`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", 
     RowBox[{"-", "1.505733071219388`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", "14.370318234634093`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.788354057852867*^9, 3.7883540881778154`*^9}, {
  3.788354150925129*^9, 3.788354207053796*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]p", "-", "\[Gamma]1"}], ")"}], "/", 
   "\[Gamma]3"}]]], "Input",
 CellChangeTimes->{{3.788354097744554*^9, 3.788354120224456*^9}}],

Cell[BoxData["14.142135623730951`"], "Output",
 CellChangeTimes->{{3.788354107414386*^9, 3.788354120686763*^9}, 
   3.788354178636717*^9, 3.7883542086459265`*^9}]
}, Open  ]],

Cell[BoxData[
 StyleBox["Plotting", "Section"]], "Input",
 CellChangeTimes->{{3.788354315780378*^9, 3.788354316581944*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fs", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "/.", "soln"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "5"}], "}"}], "\[IndentingNewLine]", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], "\[IndentingNewLine]", ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Blue", ",", 
      RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"FontSize", "\[Rule]", "fs"}], "]"}]}], "\[IndentingNewLine]", 
   ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<t\>\"", ",", 
        RowBox[{"FontSize", "\[Rule]", 
         RowBox[{"fs", "*", "1.5"}]}]}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<n(t)\>\"", ",", 
        RowBox[{"FontSize", "\[Rule]", 
         RowBox[{"fs", "*", "1.5"}]}]}], "]"}]}], "\[IndentingNewLine]", 
     "}"}]}], "\[IndentingNewLine]", ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.7883543257964554`*^9, 3.788354342624344*^9}, {
  3.788354394477992*^9, 3.7883545586006727`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 0, 1], Thickness[0.0051], LineBox[CompressedData["
1:eJwd13k0lF0YAHAGY5nBDNooS2SdISWkdJ8WFNosRURkK0IlKrRIdpFki6yl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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox[
     StyleBox["\"t\"", FontSize -> 45., StripOnInput -> False], 
     TraditionalForm], 
    FormBox[
     StyleBox["\"n(t)\"", FontSize -> 45., StripOnInput -> False], 
     TraditionalForm]},
  FrameStyle->Directive[FontSize -> 30],
  ImageSize->600,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7883544844803224`*^9, 3.788354555639595*^9}}]
}, Open  ]],

Cell[BoxData[
 StyleBox["Experiment", "Section"]], "Input",
 CellChangeTimes->{{3.78877601490816*^9, 3.7887760224154587`*^9}}],

Cell[TextData[{
 StyleBox["Units: ",
  FontFamily->"Times New Roman",
  FontSize->20,
  FontWeight->"Bold",
  FontColor->RGBColor[1., 0., 0.]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Mu]m", "3"], " ", "and", " ", "seconds"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",
  FontSize->20,
  FontWeight->"Bold",
  FontColor->RGBColor[1., 0., 0.]]
}], "Text",
 CellChangeTimes->{{3.7887857057482605`*^9, 3.7887857175955935`*^9}, {
  3.7887857885977736`*^9, 3.788785797946365*^9}, {3.788785975322754*^9, 
  3.7887859998900337`*^9}},
 FormatType->"TextForm"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]1", "=", 
    RowBox[{"1", "/", "3"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"1", "-", 
    RowBox[{"body", " ", "loss", " ", "in", " ", "Hz"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]3", "=", 
    RowBox[{"2", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "5"}]]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"3", "-", 
    RowBox[{"body", " ", "loss", " ", "in", " ", 
     RowBox[{"Hz", "\[Cross]", 
      SuperscriptBox["\[Mu]m", "6"]}]}]}], "  ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]p", "=", 
    RowBox[{"5000", "/", "225"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"pump", " ", "rate", " ", "in", " ", "Hz"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VBEC", "=", "20"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Volume", " ", "of", " ", "BEC", " ", "in", " ", 
    SuperscriptBox["\[Mu]m", "3"]}], " ", 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.788776082012403*^9, {3.7887783698518624`*^9, 3.7887784015307446`*^9}, {
   3.7887784520913935`*^9, 3.788778469499674*^9}, {3.788778729590412*^9, 
   3.7887787296424484`*^9}, {3.788778868834586*^9, 3.788778873548912*^9}, {
   3.788779111303625*^9, 3.7887791375031195`*^9}, {3.788779395717784*^9, 
   3.788779625172923*^9}, {3.788779671517578*^9, 3.788779693440737*^9}, {
   3.788779731197341*^9, 3.788779734449666*^9}, {3.788779770578122*^9, 
   3.788779830969187*^9}, {3.7887799022841225`*^9, 3.788779973572113*^9}, {
   3.7887831833673368`*^9, 3.7887831873441944`*^9}, {3.7887835697002215`*^9, 
   3.7887835698682575`*^9}, 3.7887836478178663`*^9, {3.7887839396133027`*^9, 
   3.7887839642178373`*^9}, {3.788785310296364*^9, 3.7887853610466604`*^9}, {
   3.788785607630931*^9, 3.7887856992436666`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tend", "=", "1.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"soln", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Gamma]1"}], " ", 
          RowBox[{"n", "[", "t", "]"}]}], "-", 
         RowBox[{"0", "g2", " ", 
          SuperscriptBox[
           RowBox[{"n", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"\[Gamma]3", " ", 
          SuperscriptBox[
           RowBox[{"n", "[", "t", "]"}], "3"]}], "+", " ", 
         RowBox[{"\[Gamma]p", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"n", "[", "t", "]"}], "+", 
            RowBox[{"1", "/", "VBEC"}]}], ")"}]}]}]}], ",", 
       RowBox[{
        RowBox[{"n", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", "n", 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tend"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7887784209334145`*^9, 3.788778436703539*^9}, {
   3.7887785208818693`*^9, 3.788778521027958*^9}, {3.7887788393163815`*^9, 
   3.7887788403190956`*^9}, {3.788779642605233*^9, 3.7887796481501293`*^9}, {
   3.788779708245167*^9, 3.7887797185254197`*^9}, {3.7887832999612513`*^9, 
   3.7887833038076315`*^9}, 3.7887838752540092`*^9, 3.788785244343549*^9, {
   3.788785367529233*^9, 3.788785368099614*^9}, {3.7887854003214664`*^9, 
   3.788785410760829*^9}, {3.788785559483881*^9, 3.788785578152288*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fs", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "/.", "soln"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"n", "[", "t", "]"}], "/.", 
       RowBox[{"sol0", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g", "\[Rule]", 
         RowBox[{"\[Gamma]p", "-", "\[Gamma]1"}]}], ",", 
        RowBox[{"g3", "\[Rule]", "\[Gamma]3"}], ",", 
        RowBox[{
         RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}]}], "}"}]}], "]"}], 
    "*)"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tend"}], "}"}], "\[IndentingNewLine]", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], "\[IndentingNewLine]", ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Blue", ",", 
      RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"FontSize", "\[Rule]", "fs"}], "]"}]}], "\[IndentingNewLine]", 
   ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<t [s]\>\"", ",", 
        RowBox[{"FontSize", "\[Rule]", "fs"}]}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<n(t) [atoms/\!\(\*SuperscriptBox[\(\[Mu]m\), \(3\)]\)]\>\"", ",", 
        RowBox[{"FontSize", "\[Rule]", "fs"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.7887785701641307`*^9, 3.7887786441121206`*^9}, {
  3.788778813323059*^9, 3.7887788177411623`*^9}, {3.7887796554392524`*^9, 
  3.7887796560136557`*^9}, {3.7887797233107924`*^9, 3.788779723838163*^9}, {
  3.7887854300711584`*^9, 3.788785467656773*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 0, 1], Thickness[0.005], LineBox[CompressedData["
1:eJwl13k4lN8XAHCpKITsW7ZIihJJJOeSpD17ibLvsqQoJftaDCq7JBTJvkd2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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox[
     StyleBox["\"t [s]\"", FontSize -> 30, StripOnInput -> False], 
     TraditionalForm], 
    FormBox[
     StyleBox[
     "\"n(t) [atoms/\\!\\(\\*SuperscriptBox[\\(\[Mu]m\\), \\(3\\)]\\)]\"", 
      FontSize -> 30, StripOnInput -> False], TraditionalForm]},
  FrameStyle->Directive[FontSize -> 30],
  ImageSize->600,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.788778414689025*^9, 3.7887784384607925`*^9}, 
   3.7887785270712166`*^9, {3.7887785920385447`*^9, 3.7887786450517836`*^9}, 
   3.7887787326015453`*^9, {3.788778821294669*^9, 3.788778876269844*^9}, {
   3.7887796500454807`*^9, 3.788779656360905*^9}, {3.7887796985493293`*^9, 
   3.7887797377229595`*^9}, {3.7887797753204765`*^9, 3.7887798366588354`*^9}, 
   3.7887798812813087`*^9, {3.78877992226723*^9, 3.788779947189516*^9}, 
   3.7887799848350687`*^9, 3.7887833437527466`*^9, 3.788783601898246*^9, 
   3.788783652832905*^9, 3.788783919900657*^9, {3.788783975736346*^9, 
   3.7887839802089405`*^9}, {3.7887853828799443`*^9, 3.788785411984684*^9}, {
   3.7887854601290703`*^9, 3.7887854682832274`*^9}, {3.788785562209035*^9, 
   3.7887855801445355`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"#", " ", "of", " ", "steady", " ", "state", " ", "BEC", " ", 
    RowBox[{"atoms", " ", "[", "analytics", "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"NBECSS", "=", 
   RowBox[{
    RowBox[{"VBEC", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Gamma]p", "-", "\[Gamma]1"}], ")"}], "/", "\[Gamma]3"}]]}],
     "//", "N"}]}]}]], "Input",
 CellChangeTimes->{{3.788778990396985*^9, 3.788778999344279*^9}, {
   3.7887790410726967`*^9, 3.7887790472080407`*^9}, 3.788783197566901*^9, {
   3.788785478903727*^9, 3.7887855370340505`*^9}, {3.788786034141059*^9, 
   3.788786037506463*^9}}],

Cell[BoxData["20923.13976863362`"], "Output",
 CellChangeTimes->{{3.788778995710702*^9, 3.788778999599457*^9}, 
   3.788779047896522*^9, 3.7887797470094943`*^9, {3.788783193226075*^9, 
   3.7887831981910763`*^9}, 3.7887838778866096`*^9, 3.788783968292445*^9, {
   3.7887854749098935`*^9, 3.7887854923817883`*^9}, 3.7887860383810644`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]p", "//", "N"}]], "Input",
 CellChangeTimes->{{3.7887855009308405`*^9, 3.788785507454441*^9}}],

Cell[BoxData["22.22222222222222`"], "Output",
 CellChangeTimes->{{3.7887855045233655`*^9, 3.788785507708598*^9}}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.788784028717837*^9, 3.788784036101486*^9}, 
   3.7887854984861135`*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7887841260030785`*^9, 3.7887841312240014`*^9}}]
},
WindowSize->{1093, 723},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 187, 4, 58, "Input"],
Cell[747, 26, 283, 6, 33, "Input"],
Cell[1033, 34, 255, 5, 33, "Input"],
Cell[1291, 41, 567, 17, 31, "Input"],
Cell[1861, 60, 331, 6, 33, "Input"],
Cell[CellGroupData[{
Cell[2217, 70, 567, 16, 33, "Input"],
Cell[2787, 88, 547, 11, 21, "Message"],
Cell[3337, 101, 968, 30, 66, "Output"]
}, Open  ]],
Cell[4320, 134, 653, 17, 52, "Input"],
Cell[4976, 153, 280, 6, 54, "Input"],
Cell[5259, 161, 377, 9, 72, "Input"],
Cell[5639, 172, 148, 3, 39, "Input"],
Cell[CellGroupData[{
Cell[5812, 179, 955, 21, 132, "Input"],
Cell[6770, 202, 1816, 35, 340, "Output"]
}, Open  ]],
Cell[8601, 240, 227, 4, 39, "Input"],
Cell[8831, 246, 1218, 36, 53, "Input"],
Cell[CellGroupData[{
Cell[10074, 286, 705, 19, 33, "Input"],
Cell[10782, 307, 1510, 41, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12329, 353, 1464, 36, 132, "Input"],
Cell[13796, 391, 2337, 46, 384, "Output"],
Cell[16136, 439, 531, 10, 21, "Message"],
Cell[16670, 451, 528, 10, 21, "Message"],
Cell[17201, 463, 531, 10, 21, "Message"],
Cell[17735, 475, 535, 11, 21, "Message"],
Cell[18273, 488, 531, 10, 21, "Message"],
Cell[18807, 500, 528, 10, 21, "Message"],
Cell[19338, 512, 531, 10, 21, "Message"],
Cell[19872, 524, 533, 11, 21, "Message"],
Cell[20408, 537, 531, 10, 21, "Message"],
Cell[20942, 549, 529, 10, 21, "Message"],
Cell[21474, 561, 528, 10, 21, "Message"],
Cell[22005, 573, 533, 11, 21, "Message"],
Cell[22541, 586, 528, 10, 21, "Message"],
Cell[23072, 598, 529, 10, 21, "Message"],
Cell[23604, 610, 531, 10, 21, "Message"],
Cell[24138, 622, 535, 11, 21, "Message"]
}, Open  ]],
Cell[24688, 636, 122, 2, 31, "Input"],
Cell[24813, 640, 350, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[25188, 651, 948, 23, 33, "Input"],
Cell[26139, 676, 1687, 49, 61, "Output"]
}, Open  ]],
Cell[27841, 728, 1735, 41, 152, "Input"],
Cell[CellGroupData[{
Cell[29601, 773, 619, 11, 52, "Input"],
Cell[30223, 786, 143, 3, 30, "Output"]
}, Open  ]],
Cell[30381, 792, 1160, 32, 33, "Input",
 CellID->5423],
Cell[CellGroupData[{
Cell[31566, 828, 1786, 44, 228, "Input",
 CellID->28908],
Cell[33355, 874, 2531, 52, 330, "Output"],
Cell[35889, 928, 530, 10, 21, "Message"],
Cell[36422, 940, 532, 10, 21, "Message"],
Cell[36957, 952, 530, 10, 21, "Message"],
Cell[37490, 964, 535, 11, 21, "Message"],
Cell[38028, 977, 589, 12, 21, "Message"],
Cell[38620, 991, 512, 11, 21, "Message"],
Cell[39135, 1004, 585, 11, 21, "Message"],
Cell[39723, 1017, 510, 11, 21, "Message"],
Cell[40236, 1030, 583, 11, 21, "Message"],
Cell[40822, 1043, 583, 11, 21, "Message"],
Cell[41408, 1056, 535, 11, 21, "Message"],
Cell[41946, 1069, 584, 12, 21, "Message"],
Cell[42533, 1083, 586, 12, 21, "Message"],
Cell[43122, 1097, 545, 11, 21, "Message"],
Cell[43670, 1110, 510, 11, 21, "Message"],
Cell[44183, 1123, 585, 11, 21, "Message"],
Cell[44771, 1136, 583, 11, 21, "Message"],
Cell[45357, 1149, 583, 11, 21, "Message"],
Cell[45943, 1162, 535, 11, 21, "Message"],
Cell[46481, 1175, 583, 12, 21, "Message"],
Cell[47067, 1189, 584, 12, 21, "Message"],
Cell[47654, 1203, 586, 12, 21, "Message"],
Cell[48243, 1217, 547, 11, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48827, 1233, 211, 6, 31, "Input"],
Cell[49041, 1241, 460, 12, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49538, 1258, 204, 6, 35, "Input"],
Cell[49745, 1266, 162, 2, 30, "Output"]
}, Open  ]],
Cell[49922, 1271, 123, 2, 39, "Input"],
Cell[CellGroupData[{
Cell[50070, 1277, 1480, 36, 232, "Input"],
Cell[51553, 1315, 10590, 183, 425, "Output"]
}, Open  ]],
Cell[62158, 1501, 126, 2, 39, "Input"],
Cell[62287, 1505, 584, 19, 37, "Text"],
Cell[62874, 1526, 1900, 46, 112, "Input"],
Cell[64777, 1574, 1561, 38, 54, "Input"],
Cell[CellGroupData[{
Cell[66363, 1616, 2194, 53, 302, "Input"],
Cell[68560, 1671, 16090, 271, 394, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84687, 1947, 676, 17, 54, "Input"],
Cell[85366, 1966, 337, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85740, 1975, 126, 2, 31, "Input"],
Cell[85869, 1979, 113, 1, 30, "Output"]
}, Open  ]],
Cell[85997, 1983, 120, 2, 31, "Input"],
Cell[86120, 1987, 96, 1, 31, "Input"]
}
]
*)

(* End of internal cache information *)
