(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     22579,        618]
NotebookOptionsPosition[     21245,        571]
NotebookOutlinePosition[     21610,        587]
CellTagsIndexPosition[     21567,        584]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 StyleBox[
  RowBox[{"Rate", " ", "Equation", " ", "for", " ", "SS", " ", "BEC"}], 
  "Title"]], "Input",
 CellChangeTimes->{{3.7877230045764613`*^9, 3.787723021518431*^9}}],

Cell[BoxData[
 StyleBox[Cell[TextData[StyleBox["Remark: Notes in pdf to be added",
   FontFamily->"Times New Roman",
   FontSize->14,
   FontWeight->"Plain"]]], "DisplayFormula"]], "Input",
 CellChangeTimes->{{3.7877230389217367`*^9, 3.787723061734108*^9}, 
   3.787723291671734*^9}],

Cell[BoxData[Cell[TextData[StyleBox["This is the rate equation with \
1,2,3-body losses and pump p",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Plain"]]]], "Input",
 CellChangeTimes->{{3.7877233313387613`*^9, 3.7877233548703623`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"n", "'"}], "[", "t", "]"}], "=", 
  RowBox[{
   RowBox[{"\[Gamma]3", " ", 
    SuperscriptBox[
     RowBox[{"n", "[", "t", "]"}], "3"]}], "+", 
   RowBox[{"\[Gamma]2", " ", 
    SuperscriptBox[
     RowBox[{"n", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"\[Gamma]1", " ", 
    RowBox[{"n", "[", "t", "]"}]}], " ", "-", " ", 
   RowBox[{"\[Gamma]p", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"n", "[", "t", "]"}], "+", "1"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.787723360666478*^9, 3.7877233930143337`*^9}}],

Cell[BoxData[Cell[TextData[StyleBox["The SS solution is given by solving a \
cubic polynomial; Analytic expressions are in principle available, but ugly \
and not so insightful",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Plain"]]]], "Input",
 CellChangeTimes->{{3.787723399571973*^9, 3.7877234578312473`*^9}}],

Cell[BoxData[
 RowBox[{"solSS", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]3", " ", 
        SuperscriptBox["n", "3"]}], "+", 
       RowBox[{"\[Gamma]2", " ", 
        SuperscriptBox["n", "2"]}], "+", 
       RowBox[{"\[Gamma]1", " ", "n"}], " ", "-", " ", 
       RowBox[{"\[Gamma]p", 
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}]}]}], "\[Equal]", "0"}], ",", "n"}], 
    "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7876670727319174`*^9, 3.7876671102717457`*^9}, {
  3.78772540303576*^9, 3.7877254031798496`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Gamma]3", " ", 
      SuperscriptBox["n", "3"]}], "+", 
     RowBox[{"\[Gamma]2", " ", 
      SuperscriptBox["n", "2"]}], "+", 
     RowBox[{"\[Gamma]1", " ", "n"}], " ", "-", " ", 
     RowBox[{"\[Gamma]p", 
      RowBox[{"(", 
       RowBox[{"n", "+", "1"}], ")"}]}]}]}], ";", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"SS", " ", "polynomial"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.787667294917568*^9, 3.7876672998870816`*^9}, {
   3.78772348017301*^9, 3.7877234855087996`*^9}, 3.787723542066753*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", Cell[TextData[StyleBox[
  "pick up some random numbers for the decay rates",
   FontFamily->"Times New Roman",
   FontSize->14,
   FontWeight->"Plain"]]]}]], "Input",
 CellChangeTimes->{{3.7877235070480266`*^9, 3.787723533051383*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]3", "=", "0.01"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]2", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]1", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7876673031824017`*^9, 3.7876673262697163`*^9}, {
  3.7877234900940485`*^9, 3.7877235045662737`*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"STEADY", " ", "STATE"}], "Section"]], "Input",
 CellChangeTimes->{{3.787668323351925*^9, 3.787668334850048*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]p", "=", "\[Gamma]pin"}], ";", 
      RowBox[{"p", "[", "n", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "10"}], "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "All"}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "\"\<p[n]\>\""}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"\[Gamma]pin", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7876673275025883`*^9, 3.7876673905921707`*^9}, {
  3.787667442430786*^9, 3.787667444640354*^9}, {3.7877235537360125`*^9, 
  3.7877235621679473`*^9}, {3.7877242594098253`*^9, 3.7877242779019203`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`\[Gamma]pin$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`\[Gamma]pin$$], 0, 5}}, Typeset`size$$ = {
    360., {121., 124.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`\[Gamma]pin$169955$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`\[Gamma]pin$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Gamma]pin$$, $CellContext`\[Gamma]pin$169955$$, 
         0]}, "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[$CellContext`\[Gamma]p = $CellContext`\[Gamma]pin$$; \
$CellContext`p[$CellContext`n], {$CellContext`n, 0, 10}, 
        PlotRange -> {Automatic, All}, AxesLabel -> {None, "p[n]"}], 
      "Specifications" :> {{$CellContext`\[Gamma]pin$$, 0, 5}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{409., {166., 171.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.787667358160242*^9, 3.787667391543825*^9}, 
   3.787723563059569*^9, 3.7877242785773683`*^9}]
}, Open  ]],

Cell[BoxData[
 StyleBox["DYNAMICS", "Section"]], "Input",
 CellChangeTimes->{{3.787667560482032*^9, 3.7876675606031246`*^9}, 
   3.787668272273833*^9, {3.7876683434411097`*^9, 3.787668344922165*^9}, 
   3.7876686488804502`*^9}],

Cell[BoxData[Cell[TextData[Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      StyleBox[Cell["\<\
Solve for the dynamics starting from some initial state (say no condensate, \
n[0]\[Equal]0)\
\>", "Text",
        FontFamily->"Times New Roman"],
       FontFamily->"Courier New"], 
      StyleBox[
       RowBox[{";", " ", 
        RowBox[{"In", " ", "its", " ", "present", " ", "form"}]}],
       FontFamily->"Times New Roman"]}], 
     StyleBox[",",
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FontFamily->"Times New Roman"], 
     StyleBox[
      RowBox[{
      "the", " ", "rate", " ", "equation", " ", "can", " ", "be", " ", 
       "solved", " ", "analytically"}],
      FontFamily->"Times New Roman"], 
     StyleBox[",",
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FontFamily->"Times New Roman"], 
     StyleBox[
      RowBox[{"rather", " ", "than", " ", 
       RowBox[{"numerically", "."}]}],
      FontFamily->"Times New Roman"]}], "Text",
    FontSize->14,
    FontWeight->"Plain"], TraditionalForm]],
  FormatType->"TraditionalForm"]],
  FontFamily->"Times New Roman"]], "Input",
 CellChangeTimes->{{3.7877236063731875`*^9, 3.787723808137756*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"g", " ", 
       RowBox[{"n", "[", "t", "]"}]}], "-", 
      RowBox[{"g2", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"g3", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "3"]}]}]}], ",", 
    RowBox[{"n", "[", "t", "]"}], ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7876687651754694`*^9, 3.7876689292163677`*^9}, 
   3.7876691045685735`*^9, {3.787669460630685*^9, 3.787669473990121*^9}, 
   3.787670702822966*^9, 3.7877238271341877`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"InverseFunction", "[", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", "g2", " ", 
            RowBox[{"ArcTan", "[", 
             FractionBox[
              RowBox[{"g2", "+", 
               RowBox[{"2", " ", "g3", " ", "#1"}]}], 
              SqrtBox[
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["g2", "2"]}], "-", 
                RowBox[{"4", " ", "g", " ", "g3"}]}]]], "]"}]}], 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["g2", "2"]}], "-", 
             RowBox[{"4", " ", "g", " ", "g3"}]}]]], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", "#1", "]"}]}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{"g", "-", 
            RowBox[{"#1", " ", 
             RowBox[{"(", 
              RowBox[{"g2", "+", 
               RowBox[{"g3", " ", "#1"}]}], ")"}]}]}], "]"}]}], 
         RowBox[{"2", " ", "g"}]]}], "&"}], "]"}], "[", 
     RowBox[{"t", "+", 
      RowBox[{"C", "[", "1", "]"}]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.787668802902115*^9, {3.787668843851046*^9, 3.7876689299128504`*^9}, 
   3.7876691052740636`*^9, {3.7876694613591795`*^9, 3.787669474621563*^9}, 
   3.787670703835043*^9, 3.7877238371392307`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", "sol"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"g", "\[Rule]", "1"}], ",", 
         RowBox[{"g2", "\[Rule]", "g2in"}], ",", 
         RowBox[{"g3", "\[Rule]", "g3in"}], ",", 
         RowBox[{
          RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
          RowBox[{"-", "1"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "15"}], "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<n[t]\>\""}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"g2in", ",", "0.01", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"g3in", ",", "0.01", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7876689339256725`*^9, 3.7876691458427134`*^9}, {
  3.787669226995079*^9, 3.7876692668907113`*^9}, {3.7876693179147587`*^9, 
  3.7876693226981387`*^9}, {3.787669367912074*^9, 3.7876694124325285`*^9}, {
  3.7877242889537663`*^9, 3.7877243049831*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`g2in$$ = 0.01, $CellContext`g3in$$ = 0.01, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`g2in$$], 0.01, 2}, {
      Hold[$CellContext`g3in$$], 0.01, 2}}, Typeset`size$$ = {
    360., {122., 126.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`g2in$170081$$ = 
    0, $CellContext`g3in$170082$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`g2in$$ = 0.01, $CellContext`g3in$$ = 0.01},
       "ControllerVariables" :> {
        Hold[$CellContext`g2in$$, $CellContext`g2in$170081$$, 0], 
        Hold[$CellContext`g3in$$, $CellContext`g3in$170082$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        Evaluate[
         ReplaceAll[
          ReplaceAll[
           $CellContext`n[$CellContext`t], $CellContext`sol], {$CellContext`g -> 
           1, $CellContext`g2 -> $CellContext`g2in$$, $CellContext`g3 -> \
$CellContext`g3in$$, C[1] -> -1}]], {$CellContext`t, 0, 15}, 
        PlotRange -> {All, {0, Automatic}}, AxesLabel -> {"t", "n[t]"}], 
      "Specifications" :> {{$CellContext`g2in$$, 0.01, 
         2}, {$CellContext`g3in$$, 0.01, 2}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{409., {182., 187.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.7876689789655094`*^9, 3.7876690292400165`*^9}, {
   3.7876691354173603`*^9, 3.7876691462820363`*^9}, {3.7876692287763042`*^9, 
   3.787669267721266*^9}, 3.7876693239770107`*^9, {3.787669393768319*^9, 
   3.7876694135933304`*^9}, 3.787724306485137*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7876691647961173`*^9, 3.787669219173537*^9}, 
   3.7877238618447156`*^9}],

Cell[BoxData[
 FormBox[Cell[TextData[StyleBox[
  "Furthermore, when either the two or three body losses are neglected, the \
analytical solution further simplifies, yielding a simple solution for n[t]",
   FontFamily->"Times New Roman",
   FontSize->14,
   FontWeight->"Plain"]]], TraditionalForm]], "Input",
 CellChangeTimes->{3.787723875001011*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol0", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"n", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"g", " ", 
       RowBox[{"n", "[", "t", "]"}]}], "-", 
      RowBox[{"0", "g2", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"g3", " ", 
       SuperscriptBox[
        RowBox[{"n", "[", "t", "]"}], "3"]}]}]}], ",", 
    RowBox[{"n", "[", "t", "]"}], ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7876687651754694`*^9, 3.7876689292163677`*^9}, 
   3.7876691045685735`*^9, {3.787669460630685*^9, 3.787669473990121*^9}, 
   3.787670702822966*^9, 3.7877238271341877`*^9, {3.787724114371496*^9, 
   3.787724117034375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"g", " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", 
        SqrtBox["g"]}], 
       SqrtBox[
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "g", " ", 
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", "g3"}]}]]]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"g", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", 
           RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", 
       SqrtBox["g"]}], 
      SqrtBox[
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "g", " ", 
           RowBox[{"(", 
            RowBox[{"t", "+", 
             RowBox[{"C", "[", "1", "]"}]}], ")"}]}]], " ", "g3"}]}]]]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.787668802902115*^9, {3.787668843851046*^9, 3.7876689299128504`*^9}, 
   3.7876691052740636`*^9, {3.7876694613591795`*^9, 3.787669474621563*^9}, 
   3.787670703835043*^9, 3.7877238371392307`*^9, 3.787724119564155*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", "sol0"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"g", "\[Rule]", "1"}], ",", 
         RowBox[{"g2", "\[Rule]", "g2in"}], ",", 
         RowBox[{"g3", "\[Rule]", "g3in"}], ",", 
         RowBox[{
          RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
          RowBox[{"-", "1"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "15"}], "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<n[t]\>\""}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"g2in", ",", "0.01", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"g3in", ",", "0.01", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7876689339256725`*^9, 3.7876691458427134`*^9}, {
  3.787669226995079*^9, 3.7876692668907113`*^9}, {3.7876693179147587`*^9, 
  3.7876693226981387`*^9}, {3.787669367912074*^9, 3.7876694124325285`*^9}, {
  3.787724123792161*^9, 3.7877241429496913`*^9}, {3.787724318177413*^9, 
  3.787724322295333*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`g2in$$ = 0.01, $CellContext`g3in$$ = 0.01, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`g2in$$], 0.01, 2}, {
      Hold[$CellContext`g3in$$], 0.01, 2}}, Typeset`size$$ = {
    360., {121., 124.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`g2in$174326$$ = 
    0, $CellContext`g3in$174327$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`g2in$$ = 0.01, $CellContext`g3in$$ = 0.01},
       "ControllerVariables" :> {
        Hold[$CellContext`g2in$$, $CellContext`g2in$174326$$, 0], 
        Hold[$CellContext`g3in$$, $CellContext`g3in$174327$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        Evaluate[
         ReplaceAll[
          ReplaceAll[
           $CellContext`n[$CellContext`t], $CellContext`sol0], \
{$CellContext`g -> 
           1, $CellContext`g2 -> $CellContext`g2in$$, $CellContext`g3 -> \
$CellContext`g3in$$, C[1] -> -1}]], {$CellContext`t, 0, 15}, 
        PlotRange -> {All, {0, Automatic}}, PlotStyle -> Red, 
        AxesLabel -> {"t", "n[t]"}], 
      "Specifications" :> {{$CellContext`g2in$$, 0.01, 
         2}, {$CellContext`g3in$$, 0.01, 2}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{409., {180., 185.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.787724136759306*^9, 3.7877241431438165`*^9}, 
   3.7877243242877293`*^9}]
}, Open  ]]
},
WindowSize->{1093, 723},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 187, 4, 58, "Input"],
Cell[747, 26, 283, 6, 33, "Input"],
Cell[1033, 34, 255, 5, 33, "Input"],
Cell[1291, 41, 567, 17, 31, "Input"],
Cell[1861, 60, 331, 6, 33, "Input"],
Cell[2195, 68, 619, 17, 33, "Input"],
Cell[2817, 87, 655, 17, 52, "Input"],
Cell[3475, 106, 280, 6, 54, "Input"],
Cell[3758, 114, 377, 9, 72, "Input"],
Cell[4138, 125, 148, 3, 39, "Input"],
Cell[CellGroupData[{
Cell[4311, 132, 955, 21, 132, "Input"],
Cell[5269, 155, 1801, 35, 354, "Output"]
}, Open  ]],
Cell[7085, 193, 227, 4, 39, "Input"],
Cell[7315, 199, 1218, 36, 53, "Input"],
Cell[CellGroupData[{
Cell[8558, 239, 705, 19, 33, "Input"],
Cell[9266, 260, 1486, 41, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10789, 306, 1464, 36, 132, "Input"],
Cell[12256, 344, 2337, 46, 386, "Output"]
}, Open  ]],
Cell[14608, 393, 122, 2, 31, "Input"],
Cell[14733, 397, 350, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[15108, 408, 761, 20, 33, "Input"],
Cell[15872, 430, 1537, 47, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17446, 482, 1591, 38, 152, "Input"],
Cell[19040, 522, 2189, 46, 382, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
